@@ -54,6 +54,7 @@ from plaid.model.asset_holder_name import AssetHolderName
 from plaid.model.asset_owner import AssetOwner
 from plaid.model.asset_owners import AssetOwners
 from plaid.model.asset_report import AssetReport
+from plaid.model.asset_report_add_ons import AssetReportAddOns
 from plaid.model.asset_report_audit_copy_create_request import AssetReportAuditCopyCreateRequest
 from plaid.model.asset_report_audit_copy_create_response import AssetReportAuditCopyCreateResponse
 from plaid.model.asset_report_audit_copy_get_request import AssetReportAuditCopyGetRequest
@@ -166,6 +167,14 @@ from plaid.model.credit_audit_copy_token_remove_request import CreditAuditCopyTo
 from plaid.model.credit_audit_copy_token_remove_response import CreditAuditCopyTokenRemoveResponse
 from plaid.model.credit_audit_copy_token_update_request import CreditAuditCopyTokenUpdateRequest
 from plaid.model.credit_audit_copy_token_update_response import CreditAuditCopyTokenUpdateResponse
+from plaid.model.credit_bank_employer import CreditBankEmployer
+from plaid.model.credit_bank_employment import CreditBankEmployment
+from plaid.model.credit_bank_employment_get_request import CreditBankEmploymentGetRequest
+from plaid.model.credit_bank_employment_get_response import CreditBankEmploymentGetResponse
+from plaid.model.credit_bank_employment_item import CreditBankEmploymentItem
+from plaid.model.credit_bank_employment_report import CreditBankEmploymentReport
+from plaid.model.credit_bank_employment_warning import CreditBankEmploymentWarning
+from plaid.model.credit_bank_employment_warning_type import CreditBankEmploymentWarningType
 from plaid.model.credit_bank_income import CreditBankIncome
 from plaid.model.credit_bank_income_account import CreditBankIncomeAccount
 from plaid.model.credit_bank_income_account_type import CreditBankIncomeAccountType
@@ -322,6 +331,7 @@ from plaid.model.employer_verification import EmployerVerification
 from plaid.model.employers_search_request import EmployersSearchRequest
 from plaid.model.employers_search_response import EmployersSearchResponse
 from plaid.model.employment_details import EmploymentDetails
+from plaid.model.employment_source_type import EmploymentSourceType
 from plaid.model.employment_verification import EmploymentVerification
 from plaid.model.employment_verification_get_request import EmploymentVerificationGetRequest
 from plaid.model.employment_verification_get_response import EmploymentVerificationGetResponse
@@ -373,6 +383,8 @@ from plaid.model.fdx_notification_type import FDXNotificationType
 from plaid.model.fdx_party import FDXParty
 from plaid.model.fdx_party_registry import FDXPartyRegistry
 from plaid.model.fdx_party_type import FDXPartyType
+from plaid.model.fallback_auth_microdeposit_auto_verified_webhook import FallbackAuthMicrodepositAutoVerifiedWebhook
+from plaid.model.fallback_auth_microdeposit_verification_expired_webhook import FallbackAuthMicrodepositVerificationExpiredWebhook
 from plaid.model.form1099_type import Form1099Type
 from plaid.model.freddie_report_type import FreddieReportType
 from plaid.model.generic_country_code import GenericCountryCode
@@ -525,12 +537,21 @@ from plaid.model.liabilities_get_request_options import LiabilitiesGetRequestOpt
 from plaid.model.liabilities_get_response import LiabilitiesGetResponse
 from plaid.model.liabilities_object import LiabilitiesObject
 from plaid.model.liability_override import LiabilityOverride
+from plaid.model.link_callback_metadata import LinkCallbackMetadata
+from plaid.model.link_delivery_account import LinkDeliveryAccount
+from plaid.model.link_delivery_callback_webhook import LinkDeliveryCallbackWebhook
+from plaid.model.link_delivery_communication_method import LinkDeliveryCommunicationMethod
 from plaid.model.link_delivery_create_request import LinkDeliveryCreateRequest
 from plaid.model.link_delivery_create_response import LinkDeliveryCreateResponse
 from plaid.model.link_delivery_delivery_method import LinkDeliveryDeliveryMethod
 from plaid.model.link_delivery_get_request import LinkDeliveryGetRequest
 from plaid.model.link_delivery_get_response import LinkDeliveryGetResponse
+from plaid.model.link_delivery_institution import LinkDeliveryInstitution
+from plaid.model.link_delivery_metadata import LinkDeliveryMetadata
 from plaid.model.link_delivery_session_status import LinkDeliverySessionStatus
+from plaid.model.link_delivery_verification_status import LinkDeliveryVerificationStatus
+from plaid.model.link_delivery_webhook_communication_method import LinkDeliveryWebhookCommunicationMethod
+from plaid.model.link_delivery_webhook_delivery_status import LinkDeliveryWebhookDeliveryStatus
 from plaid.model.link_o_auth_correlation_id_exchange_request import LinkOAuthCorrelationIdExchangeRequest
 from plaid.model.link_o_auth_correlation_id_exchange_response import LinkOAuthCorrelationIdExchangeResponse
 from plaid.model.link_token_account_filters import LinkTokenAccountFilters
@@ -543,6 +564,8 @@ from plaid.model.link_token_create_request import LinkTokenCreateRequest
 from plaid.model.link_token_create_request_account_subtypes import LinkTokenCreateRequestAccountSubtypes
 from plaid.model.link_token_create_request_auth import LinkTokenCreateRequestAuth
 from plaid.model.link_token_create_request_deposit_switch import LinkTokenCreateRequestDepositSwitch
+from plaid.model.link_token_create_request_employment import LinkTokenCreateRequestEmployment
+from plaid.model.link_token_create_request_employment_bank_income import LinkTokenCreateRequestEmploymentBankIncome
 from plaid.model.link_token_create_request_identity_verification import LinkTokenCreateRequestIdentityVerification
 from plaid.model.link_token_create_request_income_verification import LinkTokenCreateRequestIncomeVerification
 from plaid.model.link_token_create_request_income_verification_bank_income import LinkTokenCreateRequestIncomeVerificationBankIncome
@@ -558,6 +581,7 @@ from plaid.model.link_token_get_metadata_response import LinkTokenGetMetadataRes
 from plaid.model.link_token_get_request import LinkTokenGetRequest
 from plaid.model.link_token_get_response import LinkTokenGetResponse
 from plaid.model.link_token_investments import LinkTokenInvestments
+from plaid.model.link_user_delivery_status_webhook import LinkUserDeliveryStatusWebhook
 from plaid.model.loan import Loan
 from plaid.model.loan_account_subtype import LoanAccountSubtype
 from plaid.model.loan_account_subtypes import LoanAccountSubtypes
@@ -618,6 +642,8 @@ from plaid.model.partner_end_customer_flowdown_status import PartnerEndCustomerF
 from plaid.model.partner_end_customer_o_auth_institution import PartnerEndCustomerOAuthInstitution
 from plaid.model.partner_end_customer_o_auth_institution_application_status import PartnerEndCustomerOAuthInstitutionApplicationStatus
 from plaid.model.partner_end_customer_o_auth_institution_environments import PartnerEndCustomerOAuthInstitutionEnvironments
+from plaid.model.partner_end_customer_o_auth_status_updated_values import PartnerEndCustomerOAuthStatusUpdatedValues
+from plaid.model.partner_end_customer_o_auth_status_updated_webhook import PartnerEndCustomerOAuthStatusUpdatedWebhook
 from plaid.model.partner_end_customer_questionnaire_status import PartnerEndCustomerQuestionnaireStatus
 from plaid.model.partner_end_customer_secrets import PartnerEndCustomerSecrets
 from plaid.model.partner_end_customer_status import PartnerEndCustomerStatus
@@ -739,6 +765,12 @@ from plaid.model.processor_bank_transfer_create_response import ProcessorBankTra
 from plaid.model.processor_identity_get_request import ProcessorIdentityGetRequest
 from plaid.model.processor_identity_get_response import ProcessorIdentityGetResponse
 from plaid.model.processor_number import ProcessorNumber
+from plaid.model.processor_signal_decision_report_request import ProcessorSignalDecisionReportRequest
+from plaid.model.processor_signal_decision_report_response import ProcessorSignalDecisionReportResponse
+from plaid.model.processor_signal_evaluate_request import ProcessorSignalEvaluateRequest
+from plaid.model.processor_signal_evaluate_response import ProcessorSignalEvaluateResponse
+from plaid.model.processor_signal_return_report_request import ProcessorSignalReturnReportRequest
+from plaid.model.processor_signal_return_report_response import ProcessorSignalReturnReportResponse
 from plaid.model.processor_stripe_bank_account_token_create_request import ProcessorStripeBankAccountTokenCreateRequest
 from plaid.model.processor_stripe_bank_account_token_create_response import ProcessorStripeBankAccountTokenCreateResponse
 from plaid.model.processor_token_create_request import ProcessorTokenCreateRequest
@@ -940,6 +972,7 @@ from plaid.model.transfer_get_response import TransferGetResponse
 from plaid.model.transfer_intent_authorization_decision import TransferIntentAuthorizationDecision
 from plaid.model.transfer_intent_create import TransferIntentCreate
 from plaid.model.transfer_intent_create_mode import TransferIntentCreateMode
+from plaid.model.transfer_intent_create_network import TransferIntentCreateNetwork
 from plaid.model.transfer_intent_create_request import TransferIntentCreateRequest
 from plaid.model.transfer_intent_create_response import TransferIntentCreateResponse
 from plaid.model.transfer_intent_get import TransferIntentGet
@@ -1034,6 +1067,7 @@ from plaid.model.wallet_iso_currency_code import WalletISOCurrencyCode
 from plaid.model.wallet_list_request import WalletListRequest
 from plaid.model.wallet_list_response import WalletListResponse
 from plaid.model.wallet_numbers import WalletNumbers
+from plaid.model.wallet_status import WalletStatus
 from plaid.model.wallet_transaction import WalletTransaction
 from plaid.model.wallet_transaction_amount import WalletTransactionAmount
 from plaid.model.wallet_transaction_counterparty import WalletTransactionCounterparty
